@@ -8,6 +8,8 @@ import inspect
 import textwrap
 from typing import Callable, Dict, List, Optional, Union
 
+from pydantic import validator
+
 from hera.shared import global_config
 from hera.workflows._mixins import (
     CallableTemplateMixin,
@@ -43,13 +45,20 @@ class Script(
 
     container_name: Optional[str] = None
     args: Optional[List[str]] = None
-    command: Optional[List[str]] = global_config.script_command
+    command: Optional[List[str]] = None
     lifecycle: Optional[Lifecycle] = None
     security_context: Optional[SecurityContext] = None
     source: Optional[Union[Callable, str]] = None
     working_dir: Optional[str] = None
     add_cwd_to_sys_path: bool = True
 
+    @validator("command", pre=True, always=True)
+    @classmethod
+    def _check_command(cls, v):
+        if v is None:
+            return global_config.script_command
+        return v
+
     def _get_param_script_portion(self) -> str:
         """Constructs and returns a script that loads the parameters of the specified arguments. Since Argo passes
         parameters through {{input.parameters.name}} it can be very cumbersome for users to manage that. This creates a
@@ -141,8 +150,9 @@ class Script(
             inputs = ModelInputs(parameters=func_parameters)
 
         already_set_params = {p.name for p in inputs.parameters or []}
+        already_set_artifacts = {p.name for p in inputs.artifacts or []}
         for param in func_parameters:
-            if param.name not in already_set_params:
+            if param.name not in already_set_params and param.name not in already_set_artifacts:
                 inputs.parameters = [param] if inputs.parameters is None else inputs.parameters + [param]
         return inputs
 
